@@ -18,7 +18,7 @@ class SniffModule(WifiModule, ScanMixin):
     })
     path = "auxiliary/wifi"
     
-    def run(self, filter_func=lambda *a, **kw: True):
+    def run(self, filter_func=lambda *a, **kw):
         self._filter_func = filter_func
         ScanMixin.scan(self, self.config.option('INTERFACE').value, self.config.option('TIMEOUT').value)
         delattr(self, "_filter_func")
